Graphs and Graphing Algorithms
::::::::::::::::::::::::::::::

.. toctree::
    :caption: Graphs and Graphing Algorithms
    :maxdepth: 2

    Objectives.rst
    VocabularyandDefinitions.rst
    TheGraphAbstractDataType.rst
    AnAdjacencyMatrix.rst
    AnAdjacencyList.rst
    Implementation.rst
    TheWordLadderProblem.rst
    BuildingtheWordLadderGraph.rst
    ImplementingBreadthFirstSearch.rst
    BreadthFirstSearchAnalysis.rst
    TheKnightsTourProblem.rst
    BuildingtheKnightsTourGraph.rst
    ImplementingKnightsTour.rst
    KnightsTourAnalysis.rst
    GeneralDepthFirstSearch.rst
    DepthFirstSearchAnalysis.rst
    TopologicalSorting.rst
    StronglyConnectedComponents.rst
    ShortestPathProblems.rst
    DijkstrasAlgorithm.rst
    AnalysisofDijkstrasAlgorithm.rst
    PrimsSpanningTreeAlgorithm.rst
    Summary.rst
    KeyTerms.rst
    Exercises.rst
